@@ -402,7 +402,7 @@ async def test_record_messages(wallmote_central_scene, mock_command, uuid4):
     event = client._recorded_events[0]
     assert event["record_type"] == "event"
     assert event["type"] == "value updated"
-    assert event["event"] == {
+    assert event["event_msg"] == {
         "type": "event",
         "event": {
             "source": "node",
@@ -452,7 +452,7 @@ async def test_additional_user_agent_components(client_session, url):
             {
                 "command": "initialize",
                 "messageId": "initialize",
-                "schemaVersion": 24,
+                "schemaVersion": 25,
                 "additionalUserAgentComponents": {
                     "zwave-js-server-python": __version__,
                     "foo": "bar",
