@@ -53,6 +53,9 @@ class Controller(EventBase):
         self.nodes: Dict[int, Node] = {}
         self._heal_network_progress: Optional[Dict[int, str]] = None
         self._statistics = ControllerStatistics()
+        self._firmware_update_progress: Optional[
+            ControllerFirmwareUpdateProgress
+        ] = None
         for node_state in state["nodes"]:
             node = Node(client, node_state)
             self.nodes[node.node_id] = node
@@ -193,6 +196,11 @@ class Controller(EventBase):
             return None
         return RFRegion(rf_region)
 
+    @property
+    def firmware_update_progress(self) -> Optional[ControllerFirmwareUpdateProgress]:
+        """Return firmware update progress."""
+        return self._firmware_update_progress
+
     def update(self, data: ControllerDataType) -> None:
         """Update controller data."""
         self.data = data
@@ -210,6 +218,7 @@ class Controller(EventBase):
         provisioning: Optional[
             Union[str, ProvisioningEntry, QRProvisioningInformation]
         ] = None,
+        dsk: Optional[str] = None,
     ) -> bool:
         """Send beginInclusion command to Controller."""
         # Most functionality was introduced in Schema 8
@@ -230,6 +239,9 @@ class Controller(EventBase):
                 raise ValueError(
                     "`provisioning` option is only supported with inclusion_strategy=SECURITY_S2"
                 )
+
+            if dsk is not None:
+                raise ValueError("Only one of `provisioning` and `dsk` can be provided")
             # Provisioning option was introduced in Schema 11
             require_schema = 11
             # String is assumed to be the QR code string so we can pass as is
@@ -257,6 +269,15 @@ class Controller(EventBase):
             else:
                 options["provisioning"] = provisioning.to_dict()
 
+        if dsk is not None:
+            if inclusion_strategy != InclusionStrategy.SECURITY_S2:
+                raise ValueError(
+                    "`dsk` option is only supported with inclusion_strategy=SECURITY_S2"
+                )
+
+            require_schema = 25
+            options["dsk"] = dsk
+
         data = await self.client.async_send_command(
             {
                 "command": "controller.begin_inclusion",
@@ -786,12 +807,13 @@ class Controller(EventBase):
 
     def handle_firmware_update_progress(self, event: Event) -> None:
         """Process a firmware update progress event."""
-        event.data["firmware_update_progress"] = ControllerFirmwareUpdateProgress(
-            event.data["progress"]
-        )
+        self._firmware_update_progress = event.data[
+            "firmware_update_progress"
+        ] = ControllerFirmwareUpdateProgress(event.data["progress"])
 
     def handle_firmware_update_finished(self, event: Event) -> None:
         """Process a firmware update finished event."""
+        self._firmware_update_progress = None
         event.data["firmware_update_finished"] = ControllerFirmwareUpdateResult(
             event.data["result"]
         )
